@@ -33,7 +33,8 @@ end
 local suite = setmetatable({}, {__newindex = add_test})
 
 function suite.compile_builtin_allow_deny_badname()
-   local cmdtab, msg = builtin.commands.allow({}, "badname")
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "badname")
    assert(cmdtab == false, "Internal errors should return false")
    assert(type(msg) == "table", "Internal errors should return tables")
    assert(type(msg.msg) == "string", "Internal errors should have string messages")
@@ -43,7 +44,8 @@ function suite.compile_builtin_allow_deny_badname()
 end
 
 function suite.compile_builtin_allow_deny_noreason()
-   local cmdtab, msg = builtin.commands.allow({}, "allow")
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow")
    assert(cmdtab == false, "Internal errors should return false")
    assert(type(msg) == "table", "Internal errors should return tables")
    assert(type(msg.msg) == "string", "Internal errors should have string messages")
@@ -51,7 +53,8 @@ function suite.compile_builtin_allow_deny_noreason()
 end
 
 function suite.compile_builtin_allow_deny_novariables()
-   local cmdtab, msg = builtin.commands.allow({}, "allow", "because")
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because")
    assert(type(cmdtab) == "table", "Result should be a table")
    assert(type(cmdtab.fn) == "function", "Result should contain a function")
    assert(type(cmdtab.args) == "table", "Result table should contain an args table")
@@ -62,7 +65,8 @@ function suite.compile_builtin_allow_deny_novariables()
 end
 
 function suite.run_builtin_allow_deny_novariables()
-   local cmdtab, msg = builtin.commands.allow({}, "allow", "because")
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because")
    assert(type(cmdtab) == "table", "Result should be a table")
    assert(type(cmdtab.fn) == "function", "Result should contain a function")
    assert(type(cmdtab.args) == "table", "Result table should contain an args table")
@@ -71,6 +75,16 @@ function suite.run_builtin_allow_deny_novariables()
    assert(msg == "because", "Expected reason should be 'because'")
 end
 
+function suite.run_builtin_allow_deny_baddefines()
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "boogaloo")
+   assert(cmdtab == false, "Internal errors should return false")
+   assert(type(msg) == "table", "Internal errors should return tables")
+   assert(type(msg.msg) == "string", "Internal errors should have string messages")
+   assert(msg.msg:match("boogaloo"), "Expected error should mention 'boogaloo'")
+   assert(msg.words[1] == 3, "Expected hilight to be word 3 (boogaloo)")
+end
+
 function suite.builtin_get_set_unconditional()
    builtin.get_set_last_unconditional_result("FOO")
    assert(builtin.get_set_last_unconditional_result() == "FOO",
@@ -86,7 +100,8 @@ end
 function suite.run_builtin_allow_deny_unconditional_saved()
    builtin.get_set_last_unconditional_result()
 
-   local cmdtab, msg = builtin.commands.allow({}, "allow", "because")
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because")
    assert(type(cmdtab) == "table", "Result should be a table")
    assert(type(cmdtab.fn) == "function", "Result should contain a function")
    assert(type(cmdtab.args) == "table", "Result table should contain an args table")
@@ -101,7 +116,8 @@ end
 function suite.run_builtin_allow_deny_conditional_saved()
    builtin.get_set_last_result()
 
-   local cmdtab, msg = builtin.commands.allow({}, "allow", "because", "fishes")
+   local compctx = {_lace = {defined={fishes=true}}}
+   local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "fishes")
    assert(type(cmdtab) == "table", "Result should be a table")
    assert(type(cmdtab.fn) == "function", "Result should contain a function")
    assert(type(cmdtab.args) == "table", "Result table should contain an args table")
@@ -248,7 +264,7 @@ function suite.compile_builtin_define_ok()
 end
 
 function suite.run_allow_deny_with_conditions_not_present()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -259,7 +275,7 @@ function suite.run_allow_deny_with_conditions_not_present()
 end
 
 function suite.run_allow_deny_with_condition_present_erroring()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -274,7 +290,7 @@ function suite.run_allow_deny_with_condition_present_erroring()
 end
 
 function suite.run_allow_deny_with_condition_present_failing()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -289,7 +305,7 @@ end
 
 
 function suite.run_allow_deny_with_condition_present_passing()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -304,7 +320,7 @@ function suite.run_allow_deny_with_condition_present_passing()
 end
 
 function suite.run_allow_deny_with_inverted_condition_present_failing()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "!cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -319,7 +335,7 @@ end
 
 
 function suite.run_allow_deny_with_inverted_condition_present_passing()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.allow(compctx, "allow", "because", "!cheese")
    assert(type(cmdtab) == "table", "Successful compilation returns tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -342,6 +358,15 @@ function suite.compile_include_statement_noname()
    assert(msg.msg:match("ruleset name"), "Expected error should mention a lack of name")
 end
 
+function suite.compile_include_statement_unknowncond()
+   local compctx = {_lace = {}}
+   local cmdtab, msg = builtin.commands.include(compctx, "include", "whatever", "badcond")
+   assert(cmdtab == false, "Internal errors should return false")
+   assert(type(msg) == "table", "Internal errors should return tables")
+   assert(type(msg.msg) == "string", "Internal errors should have string messages")
+   assert(msg.msg:match("badcond"), "Expected error should mention the bad condition")
+end
+
 function suite.compile_include_statement_noloader()
    local compctx = {_lace = {}}
    local cmdtab, msg = builtin.commands.include(compctx, "include", "fish")
@@ -430,7 +455,7 @@ function suite.run_cond_include_present_erroring()
    local function _loader(cctx, name)
       return name, "allow because\n"
    end
-   local compctx = {_lace = {loader=_loader}}
+   local compctx = {_lace = {loader=_loader, defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.include(compctx, "include", "fish", "cheese")
    assert(type(cmdtab) == "table", "Commands should be tables")
    assert(type(cmdtab.fn) == "function", "With a function")
@@ -454,7 +479,7 @@ function suite.run_cond_include_present_failing()
    local function _loader(cctx, name)
       return name, "allow because\n"
    end
-   local compctx = {_lace = {loader=_loader}}
+   local compctx = {_lace = {loader=_loader, defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.include(compctx, "include", "fish", "cheese")
    assert(type(cmdtab) == "table", "Commands should be tables")
    assert(type(cmdtab.fn) == "function", "With a function")
@@ -477,7 +502,7 @@ function suite.run_cond_include_present_passing()
    local function _loader(cctx, name)
       return name, "allow because\n"
    end
-   local compctx = {_lace = {loader=_loader}}
+   local compctx = {_lace = {loader=_loader, defined={cheese=true}}}
    local cmdtab, msg = builtin.commands.include(compctx, "include", "fish", "cheese")
    assert(type(cmdtab) == "table", "Commands should be tables")
    assert(type(cmdtab.fn) == "function", "With a function")
@@ -531,7 +556,7 @@ end
 
 
 function suite.compile_anyof_two_args()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={foo=true,bar=true}}}
    local cmdtab, msg = builtin.commands.define(compctx, "define", "foo", "anyof", "foo", "bar")
    assert(type(cmdtab) == "table", "Successful compilations should return tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -550,7 +575,7 @@ function suite.compile_anyof_two_args()
 end
 
 function suite.compile_allof_two_args()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={foo=true,bar=true}}}
    local cmdtab, msg = builtin.commands.define(compctx, "define", "foo", "allof", "foo", "bar")
    assert(type(cmdtab) == "table", "Successful compilations should return tables")
    assert(type(cmdtab.fn) == "function", "With functions")
@@ -593,7 +618,7 @@ function suite.run_anyof_two_args()
 end
 
 function suite.run_anyof_two_args()
-   local compctx = {_lace = {}}
+   local compctx = {_lace = {defined={foo=true,bar=true}}}
    local cmdtab, msg = builtin.commands.define(compctx, "define", "jeff", "allof", "foo", "bar")
    assert(type(cmdtab) == "table", "Successful compilations should return tables")
    local ectx = {
