@@ -73,7 +73,7 @@ function suite.no_content_no_loader()
 end
 
 function suite.no_unconditional_action()
-   local result, msg = compiler.compile({_lace = {}}, "", "deny stuff cond")
+   local result, msg = compiler.compile({_lace = {defined={cond=true}}}, "", "deny stuff cond")
    assert(type(result) == "table", "Loading a ruleset should result in a table")
    assert(#result.rules == 2, "There should be two rules present")
    local rule = result.rules[1]
@@ -89,7 +89,7 @@ function suite.no_unconditional_action()
 end
 
 function suite.no_unconditional_action_default_deny()
-   local result, msg = compiler.compile({_lace = {}}, "", "default deny\ndeny stuff cond")
+   local result, msg = compiler.compile({_lace = {defined={cond=true}}}, "", "default deny\ndeny stuff cond")
    assert(type(result) == "table", "Loading a ruleset should result in a table")
    assert(#result.rules == 3, "There should be three rules present")
    local rule = result.rules[1]
@@ -239,6 +239,30 @@ function suite.error_in_define_anyof2()
    assert(line4 == "            ^^^^^ ^^^^^^^^^", "The fourth line highlights relevant words")
 end
 
+function suite.error_in_define_anyof3()
+   local result, msg = compiler.compile(comp_context, "errorindefineanyof3")
+   assert(result == false, "Errors compiling should return false")
+   assert(type(msg) == "string", "Compilation errors should be strings")
+   assert(msg:find("\n"), "Compilation errors are multiline")
+   local line1, line2, line3, line4 = msg:match("^([^\n]*)\n([^\n]*)\n([^\n]*)\n([^\n]*)$")
+   assert(line1:find("something"), "The first line must mention the error")
+   assert(line2 == "real-errorindefineanyof3 :: 3", "The third line is where the error happened")
+   assert(line3 == "define fish anyof something else", "The third line is the original line")
+   assert(line4 == "                  ^^^^^^^^^     ", "The fourth line highlights relevant words")
+end
+
+function suite.error_in_define_anyof4()
+   local result, msg = compiler.compile(comp_context, "errorindefineanyof4")
+   assert(result == false, "Errors compiling should return false")
+   assert(type(msg) == "string", "Compilation errors should be strings")
+   assert(msg:find("\n"), "Compilation errors are multiline")
+   local line1, line2, line3, line4 = msg:match("^([^\n]*)\n([^\n]*)\n([^\n]*)\n([^\n]*)$")
+   assert(line1:find("else"), "The first line must mention the error")
+   assert(line2 == "real-errorindefineanyof4 :: 3", "The third line is where the error happened")
+   assert(line3 == "define fish anyof something else", "The third line is the original line")
+   assert(line4 == "                            ^^^^", "The fourth line highlights relevant words")
+end
+
 function suite.error_in_allow_or_deny()
    local result, msg = compiler.compile(comp_context, "errorinallow")
    assert(result == false, "Errors compiling should return false")
@@ -403,6 +427,25 @@ function suite.okay_negated_subdefine()
    assert(result, msg)
 end
 
+function suite.deep_errors_report_well()
+   local result, msg = compiler.compile(comp_context, "deeperror1")
+   local expected_err = [[
+define's second parameter (broken) must be a control type such as anyof
+real-deeperror3 :: 3
+define something broken
+                 ^^^^^^
+while including deeperror3
+real-deeperror2 :: 3
+include deeperror3
+        ^^^^^^^^^^
+while including deeperror2
+real-deeperror1 :: 3
+include deeperror2
+        ^^^^^^^^^^]]
+   assert(not result, "Err, didn't want the compilation to succeed")
+   assert(msg == expected_err, "Error message did not match")
+end
+
 local count_ok = 0
 for _, testname in ipairs(testnames) do
 --   print("Run: " .. testname)
